@@ -174,14 +174,13 @@ class Main : public QMainWindow {
 
   public slots:
     void updateQueries(VymModel *);
-    bool openURL(const QString &url);
-    void openTabs(QStringList);
-    void editOpenURL();
-    void editOpenURLTab();
+    bool openUrl(const QString &url = "", bool privateMode = false);
+    void openTabs(QStringList, bool privateMode = false);
 
   private slots:
-    void editOpenMultipleVisURLTabs(bool ignoreScrolled = true);
-    void editOpenMultipleURLTabs();
+    void editOpenMultipleVisUrls(bool ignoreScrolled = true, bool privateMode = false);
+    void editOpenMultipleUrls();
+    void editOpenMultipleUrlsPrivate();
     void editNote2URLs();
     void editURL();
     void editLocalURL();
@@ -467,7 +466,8 @@ class Main : public QMainWindow {
     QToolBar *selectionToolbar;
     QToolBar *editorsToolbar;
     QToolBar *colorsToolbar;
-    QToolBar *zoomToolbar;
+    QToolBar *viewTransformationsToolbar;
+    QToolBar *limitedViewToolbar;
     QToolBar *modModesToolbar;
     QToolBar *referencesToolbar;
     QToolBar *standardFlagsToolbar;
@@ -506,10 +506,10 @@ class Main : public QMainWindow {
     QAction *actionExpandOneLevel;
     QAction *actionCollapseOneLevel;
     QAction *actionCollapseUnselected;
-    QAction *actionOpenURL;
-    QAction *actionOpenURLTab;
-    QAction *actionOpenMultipleVisURLTabs;
-    QAction *actionOpenMultipleURLTabs;
+    QAction *actionOpenUrl;
+    QAction *actionOpenMultipleVisUrls;
+    QAction *actionOpenMultipleUrls;
+    QAction *actionOpenMultipleUrlsPrivate;
     QAction *actionGetURLsFromNote;
     QAction *actionURLNew;
     QAction *actionLocalURL;
