@@ -36,8 +36,6 @@ class ZipAgent;
 class QGraphicsScene;
 class QJsonObject;
 
-// Used for getTargets() and getLinkedMaps()
-// For each ID store heading and optionally also vymLink
 typedef QMap<uint, QStringList> ItemList;
 
 class VymModel : public TreeModel {
@@ -172,17 +170,16 @@ class VymModel : public TreeModel {
   public:
     /*! \brief Save the map to file */
     bool saveMap(const File::SaveMode &);
-    bool isLoading();
     bool isSaving();
-    bool isBusy();
 
   private slots:
     void zipFinished ();
 
   private:
+
+
     ZipAgent *zipAgent;
     bool isSavingInt;
-    bool isLoadingInt;
 
   public:
     ImageItem* loadImage(
@@ -263,16 +260,14 @@ class VymModel : public TreeModel {
     bool isRedoAvailable(); //!< True, if redo is available
     QString lastRedoSelection();
     QString lastRedoCommand();
-    QString lastRedoComment();
-    QString lastUndoCommand();
-    QString lastUndoComment();
+    QVariant repeatLastCommand(); //!< Repeat last command on current selection
 
-    void undo();                    //!< Undo last action
-    bool isUndoAvailable();         //!< True, if undo is available
-    void gotoHistoryStep(int);      //!< Goto a specifig step in history
+    void undo();               //!< Undo last action
+    bool isUndoAvailable();    //!< True, if undo is available
+    void gotoHistoryStep(int); //!< Goto a specifig step in history
 
-    QString getHistoryPath();       //!< Path to directory containing the history
-    void resetHistory();            //!< Initialize history
+    QString getHistoryPath(); //!< Path to directory containing the history
+    void resetHistory();      //!< Initialize history
 
     QString setAttributeVar(AttributeItem*, QString varName ="b");  //!< Returns command to set AttributeItem in scripts for undo/redo
     QString setBranchVar(BranchItem*, QString varName ="b");  //!< Returns command to set BranchItem in scripts for undo/redo
@@ -311,7 +306,6 @@ class VymModel : public TreeModel {
     /*! Put several states into one Script for a single undo step */
     void saveStateBeginScript(const QString &comment);
     void saveStateEndScript();
-    void saveStateCancelScript();
 
     ////////////////////////////////////////////
     // unsorted so far
@@ -599,6 +593,7 @@ class VymModel : public TreeModel {
     void deleteVymLink();                // delete link to another map
     QString getVymLink();                // return path to map
     QStringList getVymLinks();           // return paths in subtree
+    void followXLink(int);
     void editXLink();
     void setXLinkColor(const QString &, XLink *xl = nullptr);
     void setXLinkStyle(const QString &, XLink *xl = nullptr);
@@ -905,6 +900,18 @@ class VymModel : public TreeModel {
     void setSelectionBrushColor(QColor);
     QColor getSelectionBrushColor();
 
+    ////////////////////////////////////////////
+    // Iterating and selecting branches
+    ////////////////////////////////////////////
+  public:
+    void newBranchIterator(const QString &itname,
+                      BranchItem *bi = nullptr,             //! All branches or only subtree
+                      bool deepLevelsFirst = false);        //! Named iterator
+    BranchItem* nextBranchIterator(const QString &itname);  //! next branch via iterator
+  private:
+    QHash <QString, QList <QUuid>> branchIterators;
+    QHash <QString, int> branchIteratorsCurrentIndex;
+
     ////////////////////////////////////////////
     // Slide related
     ////////////////////////////////////////////
